@@ -25,7 +25,7 @@ class NoFreeze(BaseFinetuning):
     def freeze_before_training(self, pl_module: pl.LightningModule) -> None:
         pass
 
-    def finetunning_function(
+    def finetune_function(
         self,
         pl_module: pl.LightningModule,
         epoch: int,
@@ -42,7 +42,7 @@ class FlashBaseFinetuning(BaseFinetuning):
 
         FlashBaseFinetuning can be used to create a custom Flash Finetuning Callback.
 
-        Override ``finetunning_function`` to put your unfreeze logic.
+        Override ``finetune_function`` to put your unfreeze logic.
 
         Args:
             attr_names: Name(s) of the module attributes of the model to be frozen.
@@ -62,15 +62,15 @@ class FlashBaseFinetuning(BaseFinetuning):
             attr = getattr(pl_module, attr_name, None)
             if attr is None or not isinstance(attr, nn.Module):
                 MisconfigurationException(f"Your model must have a {attr} attribute")
-            self.freeze(module=attr, train_bn=train_bn)
+            self.freeze(modules=attr, train_bn=train_bn)
 
-    def finetunning_function(self, pl_module: pl.LightningModule, epoch: int, optimizer: Optimizer, opt_idx: int):
+    def finetune_function(self, pl_module: pl.LightningModule, epoch: int, optimizer: Optimizer, opt_idx: int):
         pass
 
 
 class Freeze(FlashBaseFinetuning):
 
-    def finetunning_function(
+    def finetune_function(
         self,
         pl_module: pl.LightningModule,
         epoch: int,
@@ -86,20 +86,21 @@ class FreezeUnfreeze(FlashBaseFinetuning):
         super().__init__(attr_names, train_bn)
         self.unfreeze_epoch = unfreeze_epoch
 
-    def finetunning_function(
+    def finetune_function(
         self,
         pl_module: pl.LightningModule,
         epoch: int,
         optimizer: Optimizer,
         opt_idx: int,
     ) -> None:
-        if epoch == self.unfreeze_epoch:
-            modules = [getattr(pl_module, attr_name) for attr_name in self.attr_names]
-            self.unfreeze_and_add_param_group(
-                module=modules,
-                optimizer=optimizer,
-                train_bn=self.train_bn,
-            )
+        if epoch != self.unfreeze_epoch:
+            return
+        modules = [getattr(pl_module, attr_name) for attr_name in self.attr_names]
+        self.unfreeze_and_add_param_group(
+            module=modules,
+            optimizer=optimizer,
+            train_bn=self.train_bn,
+        )
 
 
 class UnfreezeMilestones(FlashBaseFinetuning):
@@ -116,7 +117,7 @@ class UnfreezeMilestones(FlashBaseFinetuning):
 
         super().__init__(attr_names, train_bn)
 
-    def finetunning_function(
+    def finetune_function(
         self,
         pl_module: pl.LightningModule,
         epoch: int,
