@@ -71,9 +71,9 @@ class TabularData(DataModule):
     def __init__(
         self,
         train_df: DataFrame,
-        categorical_input: List,
-        numerical_input: List,
         target: str,
+        categorical_input: Optional[List] = None,
+        numerical_input: Optional[List] = None,
         valid_df: Optional[DataFrame] = None,
         test_df: Optional[DataFrame] = None,
         batch_size: int = 2,
@@ -82,6 +82,12 @@ class TabularData(DataModule):
         dfs = [train_df]
         self._test_df = None
 
+        if categorical_input is None and numerical_input is None:
+            raise RuntimeError('Both `categorical_input` and `numerical_input` are None!')
+
+        categorical_input = categorical_input if categorical_input is not None else []
+        numerical_input = numerical_input if numerical_input is not None else []
+
         if valid_df is not None:
             dfs.append(valid_df)
 
@@ -133,8 +139,8 @@ class TabularData(DataModule):
         cls,
         train_df: DataFrame,
         target: str,
-        categorical_input: List,
-        numerical_input: List,
+        categorical_input: Optional[List] = None,
+        numerical_input: Optional[List] = None,
         valid_df: Optional[DataFrame] = None,
         test_df: Optional[DataFrame] = None,
         batch_size: int = 8,
@@ -165,12 +171,12 @@ class TabularData(DataModule):
             text_data = TextClassificationData.from_files("train.csv", label_field="class", text_field="sentence")
         """
         if valid_df is None and isinstance(val_size, float) and isinstance(test_size, float):
-            assert 0 < val_size and val_size < 1
-            assert 0 < test_size and test_size < 1
+            assert 0 < val_size < 1
+            assert 0 < test_size < 1
             train_df, valid_df = train_test_split(train_df, test_size=(val_size + test_size))
 
         if test_df is None and isinstance(test_size, float):
-            assert 0 < test_size and test_size < 1
+            assert 0 < test_size < 1
             valid_df, test_df = train_test_split(valid_df, test_size=test_size)
 
         datamodule = cls(
@@ -194,8 +200,8 @@ class TabularData(DataModule):
         cls,
         train_csv: str,
         target: str,
-        categorical_input: List,
-        numerical_input: List,
+        categorical_input: Optional[List] = None,
+        numerical_input: Optional[List] = None,
         valid_csv: Optional[str] = None,
         test_csv: Optional[str] = None,
         batch_size: int = 8,
