@@ -16,7 +16,7 @@ import pathlib
 from typing import Any, Callable, List, Optional, Sequence, Tuple, Union
 
 import torch
-from PIL import Image
+from PIL import Image, UnidentifiedImageError
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torchvision import transforms as T
 from torchvision.datasets import VisionDataset
@@ -55,9 +55,13 @@ class FilepathDataset(torch.utils.data.Dataset):
         self.labels = labels or []
         self.transform = transform
         self.loader = loader
-        if self.has_labels:
+        if not self.has_dict_labels and self.has_labels:
             self.label_to_class_mapping = dict(map(reversed, enumerate(sorted(set(self.labels)))))
 
+    @property
+    def has_dict_labels(self) -> bool:
+        return isinstance(self.labels, dict)
+
     @property
     def has_labels(self) -> bool:
         return self.labels is not None
@@ -71,7 +75,12 @@ class FilepathDataset(torch.utils.data.Dataset):
         if self.transform is not None:
             img = self.transform(img)
         label = None
-        if self.has_labels:
+        if self.has_dict_labels:
+            name = os.path.splitext(filename)[0]
+            name = os.path.basename(name)
+            label = self.labels[name]
+
+        elif self.has_labels:
             label = self.labels[index]
             label = self.label_to_class_mapping[label]
         return img, label
@@ -148,12 +157,13 @@ class FlashDatasetFolder(VisionDataset):
                 )
             self.samples = img_paths
 
-    def _find_classes(self, dir):
+    @staticmethod
+    def _find_classes(folder: str):
         """
         Finds the class folders in a dataset.
 
         Args:
-            dir (string): Root directory path.
+            folder: Root directory path.
 
         Returns:
             tuple: (classes, class_to_idx) where classes are relative to (dir), and class_to_idx is a dictionary.
@@ -161,7 +171,7 @@ class FlashDatasetFolder(VisionDataset):
         Ensures:
             No class is a subdirectory of another.
         """
-        classes = [d.name for d in os.scandir(dir) if d.is_dir()]
+        classes = [d.name for d in os.scandir(folder) if d.is_dir()]
         classes.sort()
         class_to_idx = {cls_name: i for i, cls_name in enumerate(classes)}
         return classes, class_to_idx
@@ -189,14 +199,14 @@ class FlashDatasetFolder(VisionDataset):
         return len(self.samples)
 
 
-_default_train_transforms = T.Compose([
+_DEFAULT_TRAIN_TRANSFORMS = T.Compose([
     T.RandomResizedCrop(224),
     T.RandomHorizontalFlip(),
     T.ToTensor(),
     T.Normalize([0.485, 0.456, 0.406], [0.229, 0.224, 0.225]),
 ])
 
-_default_valid_transforms = T.Compose([
+_DEFAULT_VALID_TRANSFORMS = T.Compose([
     T.Resize(256),
     T.CenterCrop(224),
     T.ToTensor(),
@@ -205,15 +215,15 @@ _default_valid_transforms = T.Compose([
 
 # todo: torch.nn.modules.module.ModuleAttributeError: 'Resize' object has no attribute '_forward_hooks'
 # Find better fix and raised issue on torchvision.
-_default_valid_transforms.transforms[0]._forward_hooks = {}
+_DEFAULT_VALID_TRANSFORMS.transforms[0]._forward_hooks = {}
 
 
 class ImageClassificationDataPipeline(ClassificationDataPipeline):
 
     def __init__(
         self,
-        train_transform: Optional[Callable] = _default_train_transforms,
-        valid_transform: Optional[Callable] = _default_valid_transforms,
+        train_transform: Optional[Callable] = _DEFAULT_TRAIN_TRANSFORMS,
+        valid_transform: Optional[Callable] = _DEFAULT_VALID_TRANSFORMS,
         use_valid_transform: bool = True,
         loader: Callable = _pil_loader
     ):
@@ -231,9 +241,13 @@ class ImageClassificationDataPipeline(ClassificationDataPipeline):
         if isinstance(samples, (list, tuple)) and all(isinstance(p, str) for p in samples):
             outputs = []
             for sample in samples:
-                output = self._loader(sample)
-                transform = self._valid_transform if self._use_valid_transform else self._train_transform
-                outputs.append(transform(output))
+                try:
+                    output = self._loader(sample)
+                    transform = self._valid_transform if self._use_valid_transform else self._train_transform
+                    outputs.append(transform(output))
+                except UnidentifiedImageError:
+                    print(f'Skipping: could not read file {sample}')
+
             return outputs
         raise MisconfigurationException("The samples should either be a tensor or a list of paths.")
 
@@ -244,55 +258,93 @@ class ImageClassificationData(DataModule):
     @classmethod
     def from_filepaths(
         cls,
-        train_filepaths: Optional[Sequence[Union[str, pathlib.Path]]] = None,
+        train_filepaths: Union[str, Optional[Sequence[Union[str, pathlib.Path]]]] = None,
         train_labels: Optional[Sequence] = None,
-        train_transform: Optional[Callable] = _default_train_transforms,
-        valid_filepaths: Optional[Sequence[Union[str, pathlib.Path]]] = None,
+        train_transform: Optional[Callable] = _DEFAULT_TRAIN_TRANSFORMS,
+        valid_split: Union[None, float] = None,
+        valid_filepaths: Union[str, Optional[Sequence[Union[str, pathlib.Path]]]] = None,
         valid_labels: Optional[Sequence] = None,
-        valid_transform: Optional[Callable] = _default_valid_transforms,
-        test_filepaths: Optional[Sequence[Union[str, pathlib.Path]]] = None,
+        valid_transform: Optional[Callable] = _DEFAULT_VALID_TRANSFORMS,
+        test_filepaths: Union[str, Optional[Sequence[Union[str, pathlib.Path]]]] = None,
         test_labels: Optional[Sequence] = None,
         loader: Callable = _pil_loader,
         batch_size: int = 64,
         num_workers: Optional[int] = None,
-        **kwargs
+        seed: int = 1234,
+        **kwargs,
     ):
         """Creates a ImageClassificationData object from lists of image filepaths and labels
 
         Args:
-            train_filepaths: sequence of file paths for training dataset. Defaults to ``None``.
+            train_filepaths: string or sequence of file paths for training dataset. Defaults to ``None``.
             train_labels: sequence of labels for training dataset. Defaults to ``None``.
             train_transform: transforms for training dataset. Defaults to ``None``.
-            valid_filepaths: sequence of file paths for validation dataset. Defaults to ``None``.
+            valid_split: if not None, generates val split from train dataloader using this value.
+            valid_filepaths: string or sequence of file paths for validation dataset. Defaults to ``None``.
             valid_labels: sequence of labels for validation dataset. Defaults to ``None``.
             valid_transform: transforms for validation and testing dataset. Defaults to ``None``.
-            test_filepaths: sequence of file paths for test dataset. Defaults to ``None``.
+            test_filepaths: string or sequence of file paths for test dataset. Defaults to ``None``.
             test_labels: sequence of labels for test dataset. Defaults to ``None``.
             loader: function to load an image file. Defaults to ``None``.
             batch_size: the batchsize to use for parallel loading. Defaults to ``64``.
             num_workers: The number of workers to use for parallelized loading.
                 Defaults to ``None`` which equals the number of available CPU threads.
+            seed: Used for the train/val splits when valid_split is not None
 
         Returns:
             ImageClassificationData: The constructed data module.
 
         Examples:
             >>> img_data = ImageClassificationData.from_filepaths(["a.png", "b.png"], [0, 1]) # doctest: +SKIP
+
+        Example when labels are in .csv file::
+
+            train_labels = labels_from_categorical_csv('path/to/train.csv', 'my_id')
+            valid_labels = labels_from_categorical_csv(path/to/valid.csv', 'my_id')
+            test_labels = labels_from_categorical_csv(path/to/tests.csv', 'my_id')
+
+            data = ImageClassificationData.from_filepaths(
+                batch_size=2,
+                train_filepaths='path/to/train',
+                train_labels=train_labels,
+                valid_filepaths='path/to/valid',
+                valid_labels=valid_labels,
+                test_filepaths='path/to/test',
+                test_labels=test_labels,
+            )
+
         """
+        # enable passing in a string which loads all files in that folder as a list
+        if isinstance(train_filepaths, str):
+            train_filepaths = [os.path.join(train_filepaths, x) for x in os.listdir(train_filepaths)]
+        if isinstance(valid_filepaths, str):
+            valid_filepaths = [os.path.join(valid_filepaths, x) for x in os.listdir(valid_filepaths)]
+        if isinstance(test_filepaths, str):
+            test_filepaths = [os.path.join(test_filepaths, x) for x in os.listdir(test_filepaths)]
+
         train_ds = FilepathDataset(
             filepaths=train_filepaths,
             labels=train_labels,
             loader=loader,
             transform=train_transform,
         )
-        valid_ds = (
-            FilepathDataset(
-                filepaths=valid_filepaths,
-                labels=valid_labels,
-                loader=loader,
-                transform=valid_transform,
-            ) if valid_filepaths is not None else None
-        )
+
+        if valid_split:
+            full_length = len(train_ds)
+            train_split = int((1.0 - valid_split) * full_length)
+            valid_split = full_length - train_split
+            train_ds, valid_ds = torch.utils.data.random_split(
+                train_ds, [train_split, valid_split], generator=torch.Generator().manual_seed(seed)
+            )
+        else:
+            valid_ds = (
+                FilepathDataset(
+                    filepaths=valid_filepaths,
+                    labels=valid_labels,
+                    loader=loader,
+                    transform=valid_transform,
+                ) if valid_filepaths is not None else None
+            )
 
         test_ds = (
             FilepathDataset(
@@ -315,14 +367,14 @@ class ImageClassificationData(DataModule):
     def from_folders(
         cls,
         train_folder: Optional[Union[str, pathlib.Path]],
-        train_transform: Optional[Callable] = _default_train_transforms,
+        train_transform: Optional[Callable] = _DEFAULT_TRAIN_TRANSFORMS,
         valid_folder: Optional[Union[str, pathlib.Path]] = None,
-        valid_transform: Optional[Callable] = _default_valid_transforms,
+        valid_transform: Optional[Callable] = _DEFAULT_VALID_TRANSFORMS,
         test_folder: Optional[Union[str, pathlib.Path]] = None,
         loader: Callable = _pil_loader,
         batch_size: int = 4,
         num_workers: Optional[int] = None,
-        **kwargs
+        **kwargs,
     ):
         """
         Creates a ImageClassificationData object from folders of images arranged in this way: ::
@@ -381,11 +433,11 @@ class ImageClassificationData(DataModule):
     def from_folder(
         cls,
         folder: Union[str, pathlib.Path],
-        transform: Optional[Callable] = _default_valid_transforms,
+        transform: Optional[Callable] = _DEFAULT_VALID_TRANSFORMS,
         loader: Callable = _pil_loader,
         batch_size: int = 64,
         num_workers: Optional[int] = None,
-        **kwargs
+        **kwargs,
     ):
         """
         Creates a ImageClassificationData object from folders of images arranged in this way: ::
@@ -444,5 +496,5 @@ class ImageClassificationData(DataModule):
     @staticmethod
     def default_pipeline() -> ImageClassificationDataPipeline:
         return ImageClassificationDataPipeline(
-            train_transform=_default_train_transforms, valid_transform=_default_valid_transforms, loader=_pil_loader
+            train_transform=_DEFAULT_TRAIN_TRANSFORMS, valid_transform=_DEFAULT_VALID_TRANSFORMS, loader=_pil_loader
         )
