@@ -14,17 +14,17 @@
 from typing import Any, Callable, Mapping, Optional, Sequence, Type, Union
 
 import torch
-from pytorch_lightning.metrics import Accuracy
 from pytorch_lightning.utilities.distributed import rank_zero_warn
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from torch import nn
 from torch.nn import functional as F
+from torchmetrics import Accuracy
 
 from flash.core import Task
 from flash.core.data import TaskDataPipeline
 from flash.core.data.utils import _contains_any_tensor
 from flash.vision.backbones import backbone_and_num_features
-from flash.vision.classification.data import _default_valid_transforms, _pil_loader
+from flash.vision.classification.data import _DEFAULT_VALID_TRANSFORMS, _pil_loader
 
 
 class ImageEmbedderDataPipeline(TaskDataPipeline):
@@ -43,7 +43,7 @@ class ImageEmbedderDataPipeline(TaskDataPipeline):
 
     def __init__(
         self,
-        valid_transform: Optional[Callable] = _default_valid_transforms,
+        valid_transform: Optional[Callable] = _DEFAULT_VALID_TRANSFORMS,
         loader: Callable = _pil_loader,
     ):
         self._valid_transform = valid_transform
@@ -112,7 +112,7 @@ class ImageEmbedder(Task):
         assert pooling_fn in [torch.mean, torch.max]
         self.pooling_fn = pooling_fn
 
-        self.backbone, num_features = backbone_and_num_features(backbone, pretrained)
+        self.backbone, num_features = backbone_and_num_features(backbone, pretrained=pretrained)
 
         if embedding_dim is None:
             self.head = nn.Identity()
